``django-markwhat`` was originally created in the beginning of 2013 at home,
the bedroom division of the Alireza's place somewhere on planet earth maybe.

The PRIMARY AUTHORS are (and/or have been):

* Django & Django contributors
* Alireza Savand <alireza.savand@gmail.com>
* François‎
* Nik Nyby <nnyby@columbia.edu>

And here is an inevitably incomplete list of MUCH-APPRECIATED CONTRIBUTORS --
people who have submitted patches, reported bugs, added translations, helped
answer newbie questions, and generally made ``django-markwhat`` that much better:

* Django & Django contributors
* Alireza Savand <alireza.savand@gmail.com>
* Susan Dreher <sdreher@gmail.com>
* Tony Narlock <tony@git-pull.com>

A big THANK YOU goes to:

* François‎ for convincing Alireza to start the project.
* Guido van Rossum for creating Python.
